Summary: Server daemons for IMAP and POP network mail protocols.
Name: uw-imap
Version: 2002e
Release: 5tr
License: BSD
Group: Trustix Official
Source: ftp://ftp.cac.washington.edu/imap/imap-%{version}.tar.Z
Patch0: imap-2001a-trustix.patch
Patch1: imap-2002e-ssl.patch
Patch2: imap-2001a-overflow.patch
Patch3: imap-2002e-yn.patch
Patch4: imap-2002e-mail.patch
Buildroot: /var/tmp/%{name}-root
Requires: pam >= 0.59 inetd imapd-pam perl
Provides: imapd

%description
The imap package provides server daemons for both the IMAP (Internet
Message Access Protocol) and POP (Post Office Protocol) mail access
protocols.  The POP protocol uses a "post office" machine to collect mail
for users and allows users to download their mail to their local machine
for reading. The IMAP protocol provides the functionality of POP, but
allows a user to read mail on a remote machine without downloading it to
their local machine.

Install the imap package if you need a server to support the IMAP or the
POP mail access protocols.

%package devel
Summary: Development tools for programs which will use the IMAP library
Group: Trustix Official


%description devel
This package contains the header files and static libraries for
developing programs which will use the imap library.

%package -n libimap
Summary: c-client C API for the IMAP protocol
Group: Trustix Official

%description -n libimap
Libraries for programs which will use the IMAP library

%prep

%setup -q -n imap-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
make RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fPIC" lnp SPECIALAUTHENTICATORS=ssl \
     SSLTYPE=unix EXTRACFLAGS="-DDISABLE_POP_PROXT=1"
## create a shared library
gcc -shared -Wl,-soname,libimap.so c-client/*.o -o libimap.so.%{version}

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man8
perl -pi -e 's/ipopd/uw-ipopd/' ./src/ipopd/ipopd.8c
perl -pi -e 's/imapd/uw-imapd/' ./src/imapd/imapd.8c
install -m 644 ./src/ipopd/ipopd.8c $RPM_BUILD_ROOT%{_mandir}/man8/uw-ipopd.8
install -m 644 ./src/imapd/imapd.8c $RPM_BUILD_ROOT%{_mandir}/man8/uw-imapd.8
mkdir -p $RPM_BUILD_ROOT/usr/sbin
install -s -m 755 ./ipopd/ipop2d $RPM_BUILD_ROOT/usr/sbin/uw-ipop2d
install -s -m 755 ./ipopd/ipop3d $RPM_BUILD_ROOT/usr/sbin/uw-ipop3d
install -s -m 755 ./imapd/imapd $RPM_BUILD_ROOT/usr/sbin/uw-imapd
## Install the shared lib
mkdir -p $RPM_BUILD_ROOT/usr/lib
install -m 755 libimap.so.%{version} $RPM_BUILD_ROOT/usr/lib
ln -sf libimap.so.%{version} $RPM_BUILD_ROOT/usr/lib/libimap.so

mkdir -p $RPM_BUILD_ROOT/usr/lib
install -m 644 ./c-client/c-client.a $RPM_BUILD_ROOT/usr/lib
# without this link you need root privileges to build the mod_php4 rpm
ln -s /usr/lib/c-client.a $RPM_BUILD_ROOT/usr/lib/libc-client.a
mkdir -p $RPM_BUILD_ROOT/usr/include/imap
install -m 644 ./c-client/*.h $RPM_BUILD_ROOT/usr/include/imap
install -m 644 ./src/osdep/tops-20/shortsym.h $RPM_BUILD_ROOT/usr/include/imap

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,0755)
%{_mandir}/man8/uw-ipopd.8*
%{_mandir}/man8/uw-imapd.8*
%attr(0755,root,mail)	/usr/sbin/uw-ipop2d
%attr(0755,root,mail)	/usr/sbin/uw-ipop3d
%attr(0755,root,mail)	/usr/sbin/uw-imapd
%doc README

%files devel
%defattr(-,root,root,0755)
%doc docs/*
/usr/include/imap
/usr/lib/c-client.a
/usr/lib/libc-client.a

%files -n libimap
%defattr(-,root,root,0755)
/usr/lib/libimap*

%changelog
* Thu Oct  6 2005 Nived Gopalan <nived at comodo dot com> 2002e-5tr
- SECURITY Fix: Vulnerability in the University of Washington's IMAP Server 
  (UW-IMAP) allows attackers to execute arbitrary code. The vulnerability 
  specifically exists due to insufficient bounds checking on user-supplied values.

  The Common Vulnerabilities and Exposures project (cve.mitre.org) has
  assigned the name CAN-2005-2933 to this issue. 

* Tue Nov 10 2004 Oystein Viggen <oysteivi at trustix dot com> 2002e-4tr
- Rebuild with shared openssl

* Thu Dec 11 2003 Erlend Midttun <erlendbm at trustix dot org> 2002e-1tr
- New upstream.

* Fri Sep 12 2003 Gerald Dachs <gda at trustix dot org> 2001a-12gd
- additional link libc-client.a allows to build mod_php4 rpm without
  root privileges

* Mon Jun 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2001a-11tr
- Added %%defattr.

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2001a-10tr
- Big rebuild

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2001a-9em
- Rebuilt against glibc 2.3.2.

* Thu Feb 27 2003 Christian H. Toldnes <christht@tihlde.org>
- Added better removel of $RPM_BUILD_ROOT
- No need for PreReq when no %pre section.... perl is now only Required

* Sun Jan 19 2003 Gerald Dachs <gda at trustix dot org> 2001a-7em
- rebuilt against openssl 0.9.7

* Wed Nov 20 2002 Erlend Midttun <erlendbm at trustix dot com> 2001a-6em
- Moved PAM files to a separate package.

* Tue Aug 20 2002 Gerald Dachs <gda at trustix dot org> 2001a-5gd
- libimap is now back

* Tue Aug 20 2002 Gerald Dachs <gda at trustix dot org> 2001a-4gd
- libimap is now in a separate rpm

* Sun Jul 14 2002 Gerald Dachs <gda at trustix dot org> 2001a-3gd
- splitted package imap into packages imap and imap-libs

* Fri May 31 2002 Christian H. Toldnes <christht at trustix dot com>
- Patches for buffer overflow and partial read exploit.

* Wed May 14 2002 Erlend Midttun <erlendbm at trustix dot com>
- Upgrade to 2001a to fix pam.

* Mon Jun 11 2001 Erlend Midttun <erlendbm at trustix dot com>
- Upgraded to 2000c.

* Thu Dec 14 2000 Erlend Midttun <erlendbm at trustix dot com>
- Added SSL support
- Picked up 2000a.

* Sat Nov 25 2000 Erlend Midttun <erlendbm at trustix dot com>
- Picked up imap 2000 release.
- Added flock and pam patches from Red Hat.

* Tue May 9 2000 Per Ivar Paulsen <perp at trustix dot com>
- update to 4.7c2

* Tue May 2 2000 Per Ivar Paulsen <perp at trustix dot com>
- update to 4.7c1

* Tue Jan 25 2000 Per Ivar Paulsen <perp at trustix dot com>
- Initial release for the Trustix Secure Linux distribution.
- Added noreplace.
- Moved man and info pages to /usr/share adhering to FHS
- TODO: add better default configuration

* Thu Jan 13 2000 Preston Brown <pbrown@redhat.com>
- create static library in a subpackage 'devel' (#5098)

* Thu Jun 10 1999 Dale Lovelace <dale@redhat.com>
- add -fPIC option for sparc mod_php3 problems

* Fri Apr 09 1999 Cristian Gafton <gafton@redhat.com>
- ipop3d service name was changed to "pop" now. Clearly somebody that hasn't
  got a clue about PAM stuff is messing around with the source.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Sat Mar 13 1999 Cristian Gafton <gafton@redhat.com>
- verson 4.5
- loose the noflock patch

* Thu Dec 17 1998 Cristian Gafton <gafton@redhat.com>
- added a -vfs patch because sys/statvfs on glibc 2.1 is different from what
  is available on the sun...
- build against glibc 2.1

* Fri Sep 11 1998 Jeff Johnson <jbj@redhat.com>
- use only fcntl locking.

* Thu Sep 10 1998 Jeff Johnson <jbj@redhat.com>
- update to 4.4.
- removed g+s bit to imapd.

* Wed Jul 22 1998 Jeff Johnson <jbj@redhat.com>
- updated to 4.2.
- added g+s bit to imapd so that lock files can be created.

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Wed Apr 08 1998 Cristian Gafton <gafton@redhat.com>
- Updated to the latest imap as of today...

* Wed Dec 10 1997 Cristian Gafton <gafton@redhat.com>
- Updated to the latest imap as of today...
- Updated the pam patch to reflect the new directory organization

* Thu Oct 23 1997 Michael K. Johnson <johnsonm@redhat.com>
- Fix patch for new PAM spec compliance.

* Thu Oct 02 1997 Michael K. Johnson <johnsonm@redhat.com>
- Comply with change in PAM spec.
- Use a buildroot.

* Mon Mar 03 1997 Michael K. Johnson <johnsonm@redhat.com>
- Moved from pam.conf to pam.d

* Mon Mar 03 1997 Erik Troan <ewt@redhat.com>
- Fixed buffer overrun in server_login().
